// Rendering svg tag from HTML
const svg = d3.select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

// Creating Line graph
const render = (data) => {
  const titleText = 'My Daily Workout'; // Declare your title here

  const xValue = (d) => d.Day; // Display days on x axis
  const xAxisLabel = 'Day';

  const yValue = (d) => d.Pushups; // Display push-up value on y axis
  const yAxisLabel = 'Number of Push-ups';

  const margin = {
    top: 60,
    right: 40,
    bottom: 88,
    left: 150,
  };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  // Center g in svg
  const g = svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  // Create X scale with day names
  const xScale = d3
    .scalePoint()
    .domain(data.map(xValue))
    .range([0, innerWidth])
    .padding(0.5);

  // Creating xAxis
  const xAxis = d3
    .axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);

  // Create Y scale with push-up values
  const yScale = d3
    .scaleLinear()
    .domain([0, d3.max(data, yValue)])
    .range([innerHeight, 0])
    .nice();

  // Creating yAxis
  const yAxis = d3
    .axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);

  // Appending Y axis to the group
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();

  yAxisG
    .append('text')
    .attr('class', 'axis-label')
    .attr('y', -93)
    .attr('x', -innerHeight / 2)
    .attr('transform', 'rotate(-90)')
    .attr('text-anchor', 'middle')
    .attr('fill', 'black')
    .style('font-weight', 'bold') // Make text bold
    .style('font-size', '14px') // Increase font size
    .text(yAxisLabel);

  // Appending X axis to the group
  const xAxisG = g
    .append('g')
    .call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);

  xAxisG.select('.domain').remove();

  xAxisG
    .append('text')
    .attr('class', 'axis-label')
    .attr('y', 75)
    .attr('x', innerWidth / 2)
    .attr('text-anchor', 'middle')
    .attr('fill', 'black')
    .style('font-weight', 'bold') // Make text bold
    .style('font-size', '14px') // Increase font size
    .text(xAxisLabel);

  // Creating the line generator
  const lineGenerator = d3
    .line()
    .x((d) => xScale(xValue(d)))
    .y((d) => yScale(yValue(d)))
    .curve(d3.curveMonotoneX); // Makes the line smooth

  // Appending the line path to the group
  g.append('path')
    .attr('class', 'line-path')
    .attr('d', lineGenerator(data))
    .attr('stroke', 'steelblue')
    .attr('stroke-width', 2)
    .attr('fill', 'none');

  // Appending the title to the group
  g.append('text')
    .attr('class', 'title')
    .attr('y', -10)
    .attr('x', innerWidth / 2)
    .attr('text-anchor', 'middle')
    .style('font-size', '2em')
    .style('font-weight', 'bold')
    .text(titleText);
};

// Loading the data
d3.csv(
  'https://gist.githubusercontent.com/trivikram89/5ea855b6693fdae5cbf7516e32beb2b0/raw/29aa8b3ab4622576b5181a0b28384775e66c885a/gistfile1.csv',
).then((data) => {
  data.forEach((d) => {
    d.Pushups = +d.Pushups; // Convert to number
    d.Day = d.Day; // Ensure Day is a string representing the day
  });
  render(data);
});
